@@ -49,7 +49,7 @@ class ErrorInfo(Error):
 
     name = "use-writelines"
     code = 122
-    msg: str = "Replace `for line in lines: f.write(line)` with `f.writelines(lines)`"  # noqa: E501
+    msg: str = "Replace `for line in lines: f.write(line)` with `f.writelines(lines)`"
     categories = ("builtin", "readability")
 
 
