@@ -1,14 +1,6 @@
 from dataclasses import dataclass
 
-from mypy.nodes import (
-    CallExpr,
-    Expression,
-    ForStmt,
-    GeneratorExpr,
-    MemberExpr,
-    NameExpr,
-    Var,
-)
+from mypy.nodes import CallExpr, Expression, ForStmt, GeneratorExpr, MemberExpr, NameExpr, Var
 
 from refurb.error import Error
 
@@ -46,11 +38,9 @@ class ErrorInfo(Error):
 def get_readline_file_object(expr: Expression) -> NameExpr | None:
     match expr:
         case CallExpr(
-            callee=MemberExpr(
-                expr=NameExpr(node=Var(type=ty)) as f, name="readlines"
-            ),
+            callee=MemberExpr(expr=NameExpr(node=Var(type=ty)) as f, name="readlines"),
             args=[],
-        ) if str(ty) in ("io.TextIOWrapper", "io.BufferedReader"):
+        ) if str(ty) in {"io.TextIOWrapper", "io.BufferedReader"}:
             return f
 
     return None
