@@ -9,8 +9,8 @@ from refurb.error import Error
 @dataclass
 class ErrorInfo(Error):
     """
-    When comparing a value to multiple possible options, don't use multiple
-    `or` checks, use a single `in` expr:
+    When comparing a value to multiple possible options, don't `or` multiple
+    comparison checks, use a single `in` expr:
 
     Bad:
 
@@ -33,7 +33,7 @@ class ErrorInfo(Error):
 
     name = "use-in-oper"
     code = 108
-    categories = ["logical", "readability"]
+    categories = ("logical", "readability")
 
 
 def create_message(indices: tuple[int, int]) -> str:
@@ -53,6 +53,4 @@ def check(node: OpExpr, errors: list[Error]) -> None:
     if data := get_common_expr_in_comparison_chain(node, oper="or"):
         expr, indices = data
 
-        errors.append(
-            ErrorInfo(expr.line, expr.column, create_message(indices))
-        )
+        errors.append(ErrorInfo.from_node(expr, create_message(indices)))
