@@ -30,7 +30,7 @@ class ErrorInfo(Error):
 
     name = "use-math-constant"
     code = 152
-    categories = ["math", "readability"]
+    categories = ("math", "readability")
 
 
 CONSTANTS = {
@@ -44,14 +44,8 @@ def check(node: FloatExpr, errors: list[Error]) -> None:
     num = str(node.value)
 
     if len(num) <= 3:
-        return None
+        return
 
     for name, value in CONSTANTS.items():
         if num.startswith(value):
-            errors.append(
-                ErrorInfo(
-                    node.line,
-                    node.column,
-                    f"Replace `{num}` with `math.{name}`",
-                )
-            )
+            errors.append(ErrorInfo.from_node(node, f"Replace `{num}` with `math.{name}`"))
