@@ -1,13 +1,6 @@
 from dataclasses import dataclass
 
-from mypy.nodes import (
-    CallExpr,
-    IndexExpr,
-    NameExpr,
-    OpExpr,
-    SliceExpr,
-    StrExpr,
-)
+from mypy.nodes import CallExpr, IndexExpr, NameExpr, OpExpr, SliceExpr, StrExpr
 
 from refurb.error import Error
 
@@ -36,7 +29,7 @@ class ErrorInfo(Error):
 
     name = "use-pathlib-with-suffix"
     code = 100
-    msg: str = "Use `Path(x).with_suffix(y)` instead of slice and concat"  # noqa: E501
+    msg: str = "Use `Path(x).with_suffix(y)` instead of slice and concat"
     categories = ("pathlib",)
 
 
