@@ -20,7 +20,7 @@ class ErrorInfo(Error):
     Good:
 
     ```
-    if bool(value):
+    if value:
         pass
     ```
     """
@@ -28,10 +28,10 @@ class ErrorInfo(Error):
     name = "no-double-not"
     code = 114
     msg: str = "Replace `not not x` with `bool(x)`"
-    categories = ["builtin", "readability", "truthy"]
+    categories = ("builtin", "readability", "truthy")
 
 
 def check(node: UnaryExpr, errors: list[Error]) -> None:
     match node:
         case UnaryExpr(op="not", expr=UnaryExpr(op="not")):
-            errors.append(ErrorInfo(node.line, node.column))
+            errors.append(ErrorInfo.from_node(node))
