@@ -50,7 +50,5 @@ def check(node: NameExpr | MemberExpr, errors: list[Error]) -> None:
         case RefExpr(fullname=fullname):
             if long_name := SHORT_TO_LONG_FLAG.get(fullname):
                 errors.append(
-                    ErrorInfo.from_node(
-                        node, f"Replace `{fullname}` with `{long_name}`"
-                    )
+                    ErrorInfo.from_node(node, f"Replace `{fullname}` with `{long_name}`")
                 )
