@@ -11,7 +11,8 @@ class ErrorInfo(Error):
     The `bin()`, `oct()`, and `hex()` functions return the string
     representation of a number but with a prefix attached. If you don't want
     the prefix, you might be tempted to just slice it off, but using an
-    f-string will give you more flexibility:
+    f-string will give you more flexibility and let you work with negative
+    numbers:
 
     Bad:
 
@@ -28,7 +29,7 @@ class ErrorInfo(Error):
 
     name = "use-fstring-number-format"
     code = 116
-    categories = ["builtin", "fstring"]
+    categories = ("builtin", "fstring")
 
 
 FUNC_CONVERSIONS = {
@@ -48,9 +49,8 @@ def check(node: IndexExpr, errors: list[Error]) -> None:
             fstring = f'f"{{num:{format}}}"'
 
             errors.append(
-                ErrorInfo(
-                    node.line,
-                    node.column,
+                ErrorInfo.from_node(
+                    node,
                     f"Replace `{name_node.name}(num)[2:]` with `{fstring}`",
                 )
             )
