@@ -1,8 +1,12 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from pathlib import Path
-from typing import ClassVar
+from typing import TYPE_CHECKING, ClassVar
+
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from mypy.nodes import Node
 
 
 @dataclass(frozen=True)
@@ -40,12 +44,24 @@ class Error:
     enabled: ClassVar[bool] = True
     name: ClassVar[str | None] = None
     prefix: ClassVar[str] = "FURB"
-    categories: ClassVar[list[str]] = []
+    categories: ClassVar[tuple[str, ...]] = ()
     code: ClassVar[int]
     line: int
     column: int
     msg: str
     filename: str | None = None
+    line_end: int | None = None
+    column_end: int | None = None
 
     def __str__(self) -> str:
         return f"{self.filename}:{self.line}:{self.column + 1} [{self.prefix}{self.code}]: {self.msg}"  # noqa: E501
+
+    @classmethod
+    def from_node(cls, node: Node, msg: str | None = None) -> Error:
+        return cls(
+            node.line,
+            node.column,
+            line_end=node.end_line,
+            column_end=node.end_column,
+            msg=msg or cls.msg,
+        )
