@@ -1,9 +1,13 @@
+import json
 import re
-from collections.abc import Sequence
+import time
+from collections.abc import Callable, Sequence
+from contextlib import suppress
 from functools import cache, partial
 from importlib import metadata
 from io import StringIO
 from pathlib import Path
+from tempfile import mkstemp
 
 from mypy.build import build
 from mypy.errors import CompileError
@@ -21,17 +25,19 @@ def usage() -> None:
     print(
         """\
 usage: refurb [--ignore err] [--load path] [--debug] [--quiet] [--enable err]
-              [--disable err] [--disable-all] [--enable-all]
-              [--config-file path] [--python-version version] src [srcs...]
+              [--disable err] [--enable-all] [--disable-all]
+              [--config-file path] [--python-version version] [--verbose | -v]
+              [--format format] [--sort sort] [--timing-stats file]
+              SRC [SRCS...] [-- MYPY_ARGS]
        refurb [--help | -h]
-       refurb [--version | -v]
+       refurb [--version]
        refurb --explain err
        refurb gen
 
 Command Line Options:
 
 --help, -h            This help menu.
---version, -v         Print version information.
+--version             Print version information.
 --ignore err          Ignore an error. Can be repeated.
 --load module         Add a module to the list of paths to be searched when looking for checks. Can be repeated.
 --debug               Print the AST representation of all files that where checked.
@@ -43,13 +49,20 @@ Command Line Options:
 --disable-all         Disable all checks by default.
 --enable-all          Enable all checks by default.
 --python-version x.y  Version of the Python code being checked.
-src                   A file or folder.
+--verbose             Increase verbosity.
+--format format       Output errors in specified format. Can be "text" or "github".
+--sort sort           Sort errors by sort. Can be "filename" or "error".
+--timing-stats file   Export timing information (as JSON) to file.
+
+Positional Args:
+
+SRC                   A list of files or folders to check.
+MYPY_ARGS             Extra args to be passed directly to Mypy.
 
 
 Subcommands:
 
-gen              Generate boilerplate code for a new check, meant for
-                 developers.
+gen              Generate boilerplate code for a new check. Useful for developers.
 """
     )
 
@@ -76,8 +89,7 @@ def is_ignored_via_comment(error: Error) -> bool:
         error_codes = comment.group(1)
 
         return not error_codes or any(
-            error_code == ignore
-            for error_code in error_codes[2:].replace(",", " ").split(" ")
+            error_code == ignore for error_code in error_codes[2:].replace(",", " ").split(" ")
         )
 
     return False
@@ -88,9 +100,7 @@ def is_ignored_via_amend(error: Error, settings: Settings) -> bool:
 
     path = Path(error.filename).resolve()
     error_code = ErrorCode.from_error(type(error))
-    config_root = (
-        Path(settings.config_file).parent if settings.config_file else Path()
-    )
+    config_root = Path(settings.config_file).parent if settings.config_file else Path()
 
     for ignore in settings.ignore:
         if ignore.path:
@@ -148,13 +158,23 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
     opt.local_partial_types = True
     opt.python_version = settings.get_python_version()
 
+    mypy_timing_stats = Path(mkstemp()[1]) if settings.timing_stats else None
+    opt.timing_stats = str(mypy_timing_stats) if mypy_timing_stats else None
+
     try:
+        start = time.time()
+
         result = build(files, options=opt)
 
+        mypy_build_time = time.time() - start
+
     except CompileError as e:
         return [re.sub("^mypy: ", "refurb: ", msg) for msg in e.messages]
 
     errors: list[Error | str] = []
+    checks = load_checks(settings)
+
+    refurb_timing_stats_in_ms: dict[str, int] = {}
 
     for file in files:
         tree = result.graph[file.module].tree
@@ -164,30 +184,40 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
         if settings.debug:
             errors.append(str(tree))
 
-        checks = load_checks(settings)
+        start = time.time()
 
         visitor = RefurbVisitor(checks, settings)
 
-        tree.accept(visitor)
+        # See: https://github.com/dosisod/refurb/issues/302
+        with suppress(RecursionError):
+            visitor.accept(tree)
+
+        elapsed = time.time() - start
+
+        refurb_timing_stats_in_ms[file.module] = int(elapsed * 1_000)
 
         for error in visitor.errors:
             error.filename = file.path
 
         errors += visitor.errors
 
+    output_timing_stats(
+        settings,
+        mypy_build_time,
+        mypy_timing_stats,
+        refurb_timing_stats_in_ms,
+    )
+
+    if mypy_timing_stats:
+        mypy_timing_stats.unlink()
+
     return sorted(
-        [
-            error
-            for error in errors
-            if not should_ignore_error(error, settings)
-        ],
+        [error for error in errors if not should_ignore_error(error, settings)],
         key=partial(sort_errors, settings=settings),
     )
 
 
-def sort_errors(
-    error: Error | str, settings: Settings
-) -> tuple[str | int, ...]:
+def sort_errors(error: Error | str, settings: Settings) -> tuple[str | int, ...]:
     if isinstance(error, str):
         return ("", error)
 
@@ -227,12 +257,53 @@ def format_as_github_annotation(error: Error | str) -> str:
     )
 
 
-def format_errors(errors: Sequence[Error | str], settings: Settings) -> str:
-    formatter = (
-        format_as_github_annotation if settings.format == "github" else str
-    )
+ERROR_DIFF_PATTERN = re.compile(r"`([^`]*)`([^`]*)`([^`]*)`")
 
-    done = "\n".join(formatter(error) for error in errors)  # type: ignore
+
+def format_with_color(error: Error | str) -> str:
+    if isinstance(error, str):
+        return error
+
+    blue = "\x1b[94m"
+    yellow = "\x1b[33m"
+    gray = "\x1b[90m"
+    green = "\x1b[92m"
+    red = "\x1b[91m"
+    reset = "\x1b[0m"
+
+    # Add red/green color for diffs, assuming the 2 pairs of backticks are in the form:
+    # Replace `old` with `new`
+    if error.msg.count("`") == 4:
+        parts = [
+            f"{gray}`{red}\\1{gray}`{reset}",
+            "\\2",
+            f"{gray}`{green}\\3{gray}`{reset}",
+        ]
+
+        error.msg = ERROR_DIFF_PATTERN.sub("".join(parts), error.msg)
+
+    parts = [
+        f"{blue}{error.filename}{reset}",
+        f"{gray}:{error.line}:{error.column + 1}{reset}",
+        " ",
+        f"{yellow}[{error.prefix}{error.code}]{reset}",
+        f"{gray}:{reset}",
+        " ",
+        error.msg,
+    ]
+
+    return "".join(parts)
+
+
+def format_errors(errors: Sequence[Error | str], settings: Settings) -> str:
+    if settings.format == "github":
+        formatter: Callable[[Error | str], str] = format_as_github_annotation
+    elif settings.color:
+        formatter = format_with_color
+    else:
+        formatter = str
+
+    done = "\n".join(formatter(error) for error in errors)
 
     if not settings.quiet and any(isinstance(err, Error) for err in errors):
         done += "\n\nRun `refurb --explain ERR` to further explain an error. Use `--quiet` to silence this message"
@@ -240,6 +311,42 @@ def format_errors(errors: Sequence[Error | str], settings: Settings) -> str:
     return done
 
 
+def output_timing_stats(
+    settings: Settings,
+    mypy_total_time_spent: float,
+    mypy_timing_stats: Path | None,
+    refurb_timing_stats_in_ms: dict[str, int],
+) -> None:
+    if not settings.timing_stats:
+        return
+
+    assert mypy_timing_stats
+
+    mypy_stats: dict[str, int] = {}
+    lines = mypy_timing_stats.read_text().splitlines()
+
+    for line in lines:
+        module, micro_seconds = line.split()
+
+        mypy_stats[module] = int(micro_seconds) // 1_000
+
+    data = {
+        "mypy_total_time_spent_in_ms": int(mypy_total_time_spent * 1_000),
+        "mypy_time_spent_parsing_modules_in_ms": dict(
+            sorted(mypy_stats.items(), key=lambda x: x[1], reverse=True)
+        ),
+        "refurb_time_spent_checking_file_in_ms": dict(
+            sorted(
+                refurb_timing_stats_in_ms.items(),
+                key=lambda x: x[1],
+                reverse=True,
+            )
+        ),
+    }
+
+    settings.timing_stats.write_text(json.dumps(data, separators=(",", ":")))
+
+
 def main(args: list[str]) -> int:
     try:
         settings = load_settings(args)
