@@ -1,3 +1,4 @@
+import pathlib
 from pathlib import Path
 
 # these will match
@@ -7,6 +8,8 @@ a = str(Path("file.txt"))[:4] + ".pdf"
 p = Path("file.txt")
 b = str(p)[:4] + ".pdf"
 
+a = str(pathlib.Path("file.txt"))[:4] + ".pdf"
+
 
 # these will not
 
