@@ -1,3 +1,4 @@
+import contextlib
 from contextlib import nullcontext, suppress
 
 # these will match
@@ -31,3 +32,7 @@ if not TYPE_CHECKING:
 x = 1
 with suppress(Exception):
     x = 2
+
+x = 1
+with contextlib.suppress(Exception):
+    x = 2
