@@ -1,3 +1,4 @@
+import functools
 from functools import cache, lru_cache
 
 # these should match
@@ -6,24 +7,28 @@ from functools import cache, lru_cache
 def f() -> None:
     pass
 
-
-# these should not
-
-@lru_cache(maxsize=None, typed=True)
+@functools.lru_cache(maxsize=None)
 def f2() -> None:
     pass
 
 
-@lru_cache(maxsize=100)
+# these should not
+
+@lru_cache(maxsize=None, typed=True)
 def f3() -> None:
     pass
 
 
-@lru_cache
+@lru_cache(maxsize=100)
 def f4() -> None:
     pass
 
 
-@cache
+@lru_cache
 def f5() -> None:
     pass
+
+
+@cache
+def f6() -> None:
+    pass
