@@ -1,4 +1,5 @@
 import os
+from os import remove, unlink
 from pathlib import Path
 
 # these should match
@@ -10,6 +11,9 @@ file = Path("file")
 os.remove(file)
 os.unlink(file)
 
+remove("file")
+unlink("file")
+
 # these should not
 
 os.remove("file", dir_fd=1)
