@@ -25,12 +25,11 @@ nums3 = tuple((7, 8, 9))  # noqa: FURB123
 
 _ = (index for index, _ in enumerate(nums3))
 
-
-# these should not
-
 for index, num in enumerate(nums):
     pass
 
+# these should not
+
 # "count" is an infinite generator. In general, we only want to warn on
 # sequence types because you can call len() on them without exhausting some
 # iterator.
@@ -39,3 +38,9 @@ for index, _ in enumerate(counter):
     pass
 
 _ = (num for index, num in enumerate(nums) if index)
+
+for index, _ in enumerate(nums):
+    print(index, _)
+
+_ = ((index, _) for index, _ in enumerate(nums))
+_ = ((_, num) for _, num in enumerate(nums))
