@@ -2,4 +2,4 @@ class C:
     x: int
 
     def __init__(self) -> None:
-        self.x = int(0)
+        self.x = int(0)  # noqa: UP018
