@@ -128,11 +128,10 @@ def test_help_flag_calls_print():
 
 
 def test_version_flag_calls_version_func():
-    for args in (["--version"], ["-v"]):
-        with patch("refurb.main.version") as p:
-            main(args)
+    with patch("refurb.main.version") as p:
+        main(["--version"])
 
-            p.assert_called_once()
+        p.assert_called_once()
 
 
 def test_explain_flag_mentioned_if_error_exists():
@@ -276,7 +275,7 @@ def test_verbose_flag_prints_message_when_all_checks_disabled() -> None:
 
 
 def test_timing_stats_outputs_stats_file() -> None:
-    with NamedTemporaryFile(mode="r") as tmp:
+    with NamedTemporaryFile(mode="r", encoding="utf8") as tmp:
         main(["test/e2e/dummy.py", "--timing-stats", tmp.name])
 
         stats_file = Path(tmp.name)
@@ -293,14 +292,34 @@ def test_timing_stats_outputs_stats_file() -> None:
             }:
                 msg = "All values must be ints"
 
-                assert all(
-                    isinstance(v, int) for v in mypy_timing.values()
-                ), msg
+                assert all(isinstance(v, int) for v in mypy_timing.values()), msg
 
-                assert all(
-                    isinstance(v, int) for v in refurb_timing.values()
-                ), msg
+                assert all(isinstance(v, int) for v in refurb_timing.values()), msg
 
                 return
 
         pytest.fail("Data is not in proper format")
+
+
+def test_color_is_enabled_by_default():
+    with patch("builtins.print") as p:
+        main(["test/data/err_123.py"])
+
+        p.assert_called_once()
+        assert "\x1b" in p.call_args[0][0]
+
+
+def test_no_color_printed_when_disabled():
+    with patch("builtins.print") as p:
+        main(["test/data/err_123.py", "--no-color"])
+
+        p.assert_called_once()
+        assert "\x1b" not in p.call_args[0][0]
+
+
+def test_error_github_actions_formatting():
+    with patch("builtins.print") as p:
+        main(["test/data/err_123.py", "--format", "github"])
+
+        p.assert_called_once()
+        assert "::error" in p.call_args[0][0]
